.. currentmodule:: aubio
.. default-domain:: py

.. members of generated classes are not yet documented

Spectral features
-----------------

This section contains the documentation for:

- :class:`dct`
- :class:`fft`
- :class:`filterbank`
- :class:`mfcc`
- :class:`pvoc`
- :class:`specdesc`
- :class:`tss`

.. autoclass:: dct

.. autoclass:: fft
  :members:

.. autoclass:: filterbank
  :members:

.. autoclass:: mfcc

.. autoclass:: pvoc
  :members:

.. autoclass:: specdesc

.. autoclass:: tss
